==> open-cluster-management-observability-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ObservabilityAddonListFluent<A extends ObservabilityAddonListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ObservabilityAddon item);
  public A setToItems(Integer index,ObservabilityAddon item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1.ObservabilityAddon... items);
  public A addAllToItems(Collection<ObservabilityAddon> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1.ObservabilityAddon... items);
  public A removeAllFromItems(Collection<ObservabilityAddon> items);
  public A removeMatchingFromItems(Predicate<ObservabilityAddonBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ObservabilityAddon> getItems();
  public List<ObservabilityAddon> buildItems();
  public ObservabilityAddon buildItem(Integer index);
  public ObservabilityAddon buildFirstItem();
  public ObservabilityAddon buildLastItem();
  public ObservabilityAddon buildMatchingItem(Predicate<ObservabilityAddonBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ObservabilityAddonBuilder> predicate);
  public A withItems(List<ObservabilityAddon> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1.ObservabilityAddon... items);
  public Boolean hasItems();
  public ObservabilityAddonListFluent.ItemsNested<A> addNewItem();
  public ObservabilityAddonListFluent.ItemsNested<A> addNewItemLike(ObservabilityAddon item);
  public ObservabilityAddonListFluent.ItemsNested<A> setNewItemLike(Integer index,ObservabilityAddon item);
  public ObservabilityAddonListFluent.ItemsNested<A> editItem(Integer index);
  public ObservabilityAddonListFluent.ItemsNested<A> editFirstItem();
  public ObservabilityAddonListFluent.ItemsNested<A> editLastItem();
  public ObservabilityAddonListFluent.ItemsNested<A> editMatchingItem(Predicate<ObservabilityAddonBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ObservabilityAddonFluent<ObservabilityAddonListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-observability-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ObservabilityAddonListFluent<A extends ObservabilityAddonListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ObservabilityAddon item);
  public A setToItems(int index,ObservabilityAddon item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1.ObservabilityAddon... items);
  public A addAllToItems(Collection<ObservabilityAddon> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1.ObservabilityAddon... items);
  public A removeAllFromItems(Collection<ObservabilityAddon> items);
  public A removeMatchingFromItems(Predicate<ObservabilityAddonBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ObservabilityAddon> getItems();
  public List<ObservabilityAddon> buildItems();
  public ObservabilityAddon buildItem(int index);
  public ObservabilityAddon buildFirstItem();
  public ObservabilityAddon buildLastItem();
  public ObservabilityAddon buildMatchingItem(Predicate<ObservabilityAddonBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ObservabilityAddonBuilder> predicate);
  public A withItems(List<ObservabilityAddon> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1.ObservabilityAddon... items);
  public Boolean hasItems();
  public ObservabilityAddonListFluent.ItemsNested<A> addNewItem();
  public ObservabilityAddonListFluent.ItemsNested<A> addNewItemLike(ObservabilityAddon item);
  public ObservabilityAddonListFluent.ItemsNested<A> setNewItemLike(int index,ObservabilityAddon item);
  public ObservabilityAddonListFluent.ItemsNested<A> editItem(int index);
  public ObservabilityAddonListFluent.ItemsNested<A> editFirstItem();
  public ObservabilityAddonListFluent.ItemsNested<A> editLastItem();
  public ObservabilityAddonListFluent.ItemsNested<A> editMatchingItem(Predicate<ObservabilityAddonBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ObservabilityAddonFluent<ObservabilityAddonListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
